@@ -343,3 +343,26 @@ class SQLServerDataSource(DataSource):
         )
 
         return sql
+
+    def sql_reference_query(
+        self,
+        columns: str,
+        table_name: str,
+        target_table_name: str,
+        join_condition: str,
+        where_condition: str,
+        limit: int | None = None,
+    ) -> str:
+        limit_sql = ""
+        if limit:
+            limit_sql = f"TOP {limit}"
+
+        sql = dedent(
+            f"""
+            SELECT {limit_sql} {columns}
+                FROM {table_name}  SOURCE
+                LEFT JOIN {target_table_name} TARGET on {join_condition}
+            WHERE {where_condition}"""
+        )
+
+        return sql
